@@ -11,6 +11,7 @@
 #include <DGuiApplicationHelper>
 
 #include "dthememanager.h"
+#include "../../3rdparty/core/settings.h"
 
 const int KEYPADHEIGHT = 350; //整体键盘的高度
 const QSize BUTTON_SIZE = QSize(69, 46); //科学模式的固定大小
@@ -230,6 +231,13 @@ void ScientificKeyPad::initButtons()
             }
         }
 
+        if (desc->button == Key_Point) {
+            QString decSym = Settings::instance()->getSystemDecimalSymbol();
+            if (decSym.isEmpty())
+                decSym = QStringLiteral(".");
+            button->setText(decSym);
+        }
+
         //stackwidget中按钮初始化
         if ((i / 6 > 0) && (i % 6 == 0 || i % 6 == 1) && i != 30 && i != 36) {
             DPushButton *pagebutton;
